summaryrefslogtreecommitdiffstats
path: root/noatun/modules/kjofol-skin
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:57:28 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:57:28 -0600
commitdc07846059a60d069687585cc72ff501a2096296 (patch)
tree432ead5b09c6ace7e804629f1f74a3ed58f003e0 /noatun/modules/kjofol-skin
parent3c299dfe48c0060272c2966fff599b3b417e2ee4 (diff)
downloadtdemultimedia-dc07846059a60d069687585cc72ff501a2096296.tar.gz
tdemultimedia-dc07846059a60d069687585cc72ff501a2096296.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'noatun/modules/kjofol-skin')
-rw-r--r--noatun/modules/kjofol-skin/kjbutton.cpp8
-rw-r--r--noatun/modules/kjofol-skin/kjequalizer.cpp2
-rw-r--r--noatun/modules/kjofol-skin/kjequalizer.h2
-rw-r--r--noatun/modules/kjofol-skin/kjloader.cpp4
-rw-r--r--noatun/modules/kjofol-skin/kjseeker.cpp2
-rw-r--r--noatun/modules/kjofol-skin/kjskinselectorwidget.ui2
-rw-r--r--noatun/modules/kjofol-skin/kjsliders.cpp20
-rw-r--r--noatun/modules/kjofol-skin/kjtextdisplay.cpp20
-rw-r--r--noatun/modules/kjofol-skin/kjvis.cpp30
-rw-r--r--noatun/modules/kjofol-skin/kjwidget.cpp4
-rw-r--r--noatun/modules/kjofol-skin/kjwidget.h4
11 files changed, 49 insertions, 49 deletions
diff --git a/noatun/modules/kjofol-skin/kjequalizer.cpp b/noatun/modules/kjofol-skin/kjequalizer.cpp
index b84a0185..d7d2b9fa 100644
--- a/noatun/modules/kjofol-skin/kjequalizer.cpp
+++ b/noatun/modules/kjofol-skin/kjequalizer.cpp
@@ -110,7 +110,7 @@ void KJEqualizer::slotUpdateBuffer()
} // for()
// whole thingy has been drawn, now set the mask
mView->setMask( regionMask );
- tqrepaint();
+ repaint();
}
void KJEqualizer::mouseMove(const TQPoint &p, bool in)
diff --git a/noatun/modules/kjofol-skin/kjequalizer.h b/noatun/modules/kjofol-skin/kjequalizer.h
index 42c64a45..18997c6f 100644
--- a/noatun/modules/kjofol-skin/kjequalizer.h
+++ b/noatun/modules/kjofol-skin/kjequalizer.h
@@ -32,7 +32,7 @@ private:
int mBandWidth;
int mBandHalfHeight;
TQPixmap mBars; // holds all slider images
- TQPixmap *mBack; // holds background of EQ for easy tqrepaint
+ TQPixmap *mBack; // holds background of EQ for easy repaint
TQPixmap *mView; // holds prepared img of all sliders
VInterpolation *mInterpEq;
};
diff --git a/noatun/modules/kjofol-skin/kjloader.cpp b/noatun/modules/kjofol-skin/kjloader.cpp
index c4339229..ad843376 100644
--- a/noatun/modules/kjofol-skin/kjloader.cpp
+++ b/noatun/modules/kjofol-skin/kjloader.cpp
@@ -142,7 +142,7 @@ KJLoader::KJLoader()
else
{
KNotifyClient::event(winId(), "warning",
- i18n("There was trouble loading skin %1. Please select another skin file.").tqarg(skin));
+ i18n("There was trouble loading skin %1. Please select another skin file.").arg(skin));
napp->preferences();
}
@@ -392,7 +392,7 @@ void KJLoader::loadSkin(const TQString &file)
show();
conserveMemory();
- tqrepaint();
+ repaint();
// update displays if we are already playing
// This happens while changing skins
diff --git a/noatun/modules/kjofol-skin/kjseeker.cpp b/noatun/modules/kjofol-skin/kjseeker.cpp
index e82a1f8e..d368e95d 100644
--- a/noatun/modules/kjofol-skin/kjseeker.cpp
+++ b/noatun/modules/kjofol-skin/kjseeker.cpp
@@ -156,7 +156,7 @@ void KJSeeker::mouseRelease(const TQPoint &pos, bool in)
return;
g = grayRgb(color);
- tqrepaint();
+ repaint();
// kdDebug(66666) << "length : " << napp->player()->getLength() << endl;
// kdDebug(66666) << "skip to: " << ((long long)g*(long long)napp->player()->getLength())/255 << endl;
diff --git a/noatun/modules/kjofol-skin/kjskinselectorwidget.ui b/noatun/modules/kjofol-skin/kjskinselectorwidget.ui
index 17bce84d..c393bc03 100644
--- a/noatun/modules/kjofol-skin/kjskinselectorwidget.ui
+++ b/noatun/modules/kjofol-skin/kjskinselectorwidget.ui
@@ -135,7 +135,7 @@
<property name="scaledContents">
<bool>false</bool>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignCenter</set>
</property>
<property name="hAlign" stdset="0">
diff --git a/noatun/modules/kjofol-skin/kjsliders.cpp b/noatun/modules/kjofol-skin/kjsliders.cpp
index 589f994f..eaba2e76 100644
--- a/noatun/modules/kjofol-skin/kjsliders.cpp
+++ b/noatun/modules/kjofol-skin/kjsliders.cpp
@@ -86,14 +86,14 @@ void KJVolumeBar::paint(TQPainter *p, const TQRect &)
TQt::CopyROP);
if (mText)
- mText->tqrepaint();
+ mText->repaint();
}
bool KJVolumeBar::mousePress(const TQPoint &pos)
{
mVolume = (pos.x()*100) / rect().width();
// kdDebug(66666) << "volume: " << mVolume << endl;
- tqrepaint();
+ repaint();
napp->player()->setVolume(mVolume);
return true;
}
@@ -112,7 +112,7 @@ void KJVolumeBar::mouseMove(const TQPoint &pos, bool in)
void KJVolumeBar::timeUpdate(int)
{
mVolume = napp->player()->volume();
- tqrepaint();
+ repaint();
}
@@ -148,7 +148,7 @@ void KJVolumeBMP::paint(TQPainter *p, const TQRect &)
TQRect from(mVolume*mCount/100*mWidth, 0, mWidth, mImages.height());
bitBlt(p->device(), rect().topLeft(), &mImages, from, TQt::CopyROP);
if (mText)
- mText->tqrepaint();
+ mText->repaint();
}
bool KJVolumeBMP::mousePress(const TQPoint &pos)
@@ -162,7 +162,7 @@ bool KJVolumeBMP::mousePress(const TQPoint &pos)
// kdDebug(66666) << "gray : " << grayRgb(color) << endl;
// kdDebug(66666) << "volume: " << mVolume << endl;
- tqrepaint();
+ repaint();
napp->player()->setVolume(mVolume);
@@ -187,7 +187,7 @@ void KJVolumeBMP::timeUpdate(int)
mOldVolume = mVolume;
- tqrepaint();
+ repaint();
}
@@ -236,7 +236,7 @@ KJPitchBMP::KJPitchBMP(const TQStringList &i, KJLoader *p)
readConfig();
if (mText)
- mText->tqrepaint();
+ mText->repaint();
}
TQString KJPitchBMP::tip()
@@ -253,7 +253,7 @@ void KJPitchBMP::paint(TQPainter *p, const TQRect &)
bitBlt(p->device(), rect().topLeft(), &mImages, from, TQt::CopyROP);
if (mText)
- mText->tqrepaint();
+ mText->repaint();
}
bool KJPitchBMP::mousePress(const TQPoint &pos)
@@ -266,7 +266,7 @@ bool KJPitchBMP::mousePress(const TQPoint &pos)
mCurrentPitch = mMinPitch + ( (grayRgb(color)*(mMaxPitch-mMinPitch)) / 255 );
// kdDebug(66666) << "[KJPitchBMP] mousePress() mCurrentPitch: " << mCurrentPitch << endl;
- tqrepaint();
+ repaint();
newFile(); // wrong naming, in fact it just sets pitch
@@ -300,7 +300,7 @@ void KJPitchBMP::timeUpdate(int)
mOldPitch = mCurrentPitch;
- tqrepaint();
+ repaint();
}
void KJPitchBMP::newFile()
diff --git a/noatun/modules/kjofol-skin/kjtextdisplay.cpp b/noatun/modules/kjofol-skin/kjtextdisplay.cpp
index e0d3028e..7bacbb13 100644
--- a/noatun/modules/kjofol-skin/kjtextdisplay.cpp
+++ b/noatun/modules/kjofol-skin/kjtextdisplay.cpp
@@ -108,7 +108,7 @@ void KJFilename::timerEvent(TQTimerEvent *)
// apply the newly created mask
mView.setMask(newMask);
- tqrepaint();
+ repaint();
}
bool KJFilename::mousePress(const TQPoint &)
@@ -142,7 +142,7 @@ void KJFilename::readConfig()
mDistance = 1;
mTimerUpdates = KJLoader::kjofol->prefs()->titleMovingUpdates();
textFont().recalcSysFont();
- mLastTitle=""; // tqinvalidate title so it gets repainted on next timeUpdate()
+ mLastTitle=""; // invalidate title so it gets repainted on next timeUpdate()
}
void KJFilename::prepareString(const TQCString &str)
@@ -255,7 +255,7 @@ void KJTime::readConfig()
// kdDebug(66666) << "KJTime::readConfig()" << endl;
countDown = napp->displayRemaining();
timeFont().recalcSysFont();
- mLastTime=""; // tqinvalidate time so it gets repainted on next timeUpdate()
+ mLastTime=""; // invalidate time so it gets repainted on next timeUpdate()
}
TQString KJTime::lengthString ( void )
@@ -325,7 +325,7 @@ void KJTime::prepareString(const TQCString &str)
mLastTime = str;
mTime = timeFont().draw(str, rect().width());
- tqrepaint();
+ repaint();
// kdDebug(66666) << "END KJTime::prepareString(const TQCString &str)" << endl;
}
@@ -398,7 +398,7 @@ bool KJVolumeText::mousePress(const TQPoint &)
void KJVolumeText::readConfig()
{
volumeFont().recalcSysFont();
- mLastVolume=""; // tqinvalidate value so it gets repainted on next timeUpdate()
+ mLastVolume=""; // invalidate value so it gets repainted on next timeUpdate()
}
void KJVolumeText::timeUpdate(int)
@@ -421,7 +421,7 @@ void KJVolumeText::prepareString(const TQCString &str)
mLastVolume = str;
mVolume = volumeFont().draw(str, rect().width());
- tqrepaint();
+ repaint();
}
TQString KJVolumeText::tip()
@@ -501,7 +501,7 @@ void KJPitchText::mouseRelease(const TQPoint &, bool in)
void KJPitchText::readConfig()
{
pitchFont().recalcSysFont();
- mLastPitch=""; // tqinvalidate value so it gets repainted on next timeUpdate()
+ mLastPitch=""; // invalidate value so it gets repainted on next timeUpdate()
}
void KJPitchText::timeUpdate(int)
@@ -529,7 +529,7 @@ void KJPitchText::prepareString(const TQCString &str)
mLastPitch = str;
mSpeed = pitchFont().draw(str, rect().width());
- tqrepaint();
+ repaint();
}
TQString KJPitchText::tip()
@@ -600,7 +600,7 @@ bool KJFileInfo::mousePress(const TQPoint &)
void KJFileInfo::readConfig()
{
textFont().recalcSysFont();
- mLastTime=""; // tqinvalidate value so it gets repainted on next timeUpdate()
+ mLastTime=""; // invalidate value so it gets repainted on next timeUpdate()
}
void KJFileInfo::timeUpdate(int)
@@ -634,7 +634,7 @@ void KJFileInfo::prepareString(const TQCString &str)
return;
mLastTime = str;
mTime = textFont().draw(str, rect().width());
- tqrepaint();
+ repaint();
}
TQString KJFileInfo::tip()
diff --git a/noatun/modules/kjofol-skin/kjvis.cpp b/noatun/modules/kjofol-skin/kjvis.cpp
index a1a4c840..7ae04d44 100644
--- a/noatun/modules/kjofol-skin/kjvis.cpp
+++ b/noatun/modules/kjofol-skin/kjvis.cpp
@@ -79,7 +79,7 @@ KJNullScope::KJNullScope(const TQStringList &l, KJLoader *parent)
mBack = new KPixmap ( TQSize(xs,ys) );
bitBlt( mBack, 0, 0, &tmp, x, y, xs, ys, TQt::CopyROP );
setRect ( x, y, xs, ys );
- tqrepaint();
+ repaint();
}
void KJNullScope::paint(TQPainter *p, const TQRect &)
@@ -98,7 +98,7 @@ void KJNullScope::mouseRelease(const TQPoint &, bool in)
if (!in) // only do something if users is still inside the button
return;
- parent()->tqrepaint(rect(), false);
+ parent()->repaint(rect(), false);
swapScope(FFT);
}
@@ -108,7 +108,7 @@ void KJNullScope::readConfig()
Visuals v = (Visuals) KJLoader::kjofol->prefs()->visType();
if ( v != Null )
{
- parent()->tqrepaint(rect(), false);
+ parent()->repaint(rect(), false);
swapScope ( v );
}
}
@@ -163,7 +163,7 @@ void KJFFT::scopeEvent(float *d, int size)
if ( !napp->player()->isPlaying() ) // don't draw if we aren't playing (either paused or stopped)
{
if ( napp->player()->isStopped() ) // clear vis-window if playing has been stopped
- parent()->tqrepaint(rect(), false);
+ parent()->repaint(rect(), false);
return;
}
@@ -203,7 +203,7 @@ void KJFFT::scopeEvent(float *d, int size)
mGradient->setMask(mGradientMask);
bitBlt ( mAnalyzer, 0, 0, mGradient, 0, 0, -1, -1, TQt::CopyROP );
- tqrepaint();
+ repaint();
}
void KJFFT::paint(TQPainter *p, const TQRect &)
@@ -225,7 +225,7 @@ void KJFFT::mouseRelease(const TQPoint &, bool in)
return;
stop();
- parent()->tqrepaint(rect(), false);
+ parent()->repaint(rect(), false);
swapScope(Mono);
}
@@ -236,7 +236,7 @@ void KJFFT::readConfig()
if ( v != FFT )
{
stop();
- parent()->tqrepaint(rect(), false);
+ parent()->repaint(rect(), false);
swapScope ( v );
return;
}
@@ -297,7 +297,7 @@ void KJStereoFFT::scopeEvent(float *left, float *right, int len)
if ( !napp->player()->isPlaying() ) // don't draw if we aren't playing (either paused or stopped)
{
if ( napp->player()->isStopped() ) // clear vis-window if playing has been stopped
- parent()->tqrepaint(rect(), false);
+ parent()->repaint(rect(), false);
return;
}
@@ -356,7 +356,7 @@ void KJStereoFFT::scopeEvent(float *left, float *right, int len)
mGradient->setMask(mGradientMask);
bitBlt ( mAnalyzer, 0, 0, mGradient, 0, 0, -1, -1, TQt::CopyROP );
- tqrepaint();
+ repaint();
}
void KJStereoFFT::paint(TQPainter *p, const TQRect &)
@@ -376,7 +376,7 @@ void KJStereoFFT::mouseRelease(const TQPoint &, bool in)
if (!in) // only do something if users is still inside the button
return;
stop();
- parent()->tqrepaint(rect(), false);
+ parent()->repaint(rect(), false);
swapScope(Null);
}
@@ -387,7 +387,7 @@ void KJStereoFFT::readConfig()
if ( v != StereoFFT )
{
stop();
- parent()->tqrepaint(rect(), false);
+ parent()->repaint(rect(), false);
swapScope ( v );
return;
}
@@ -448,7 +448,7 @@ void KJScope::scopeEvent(float *d, int size)
if ( napp->player()->isStopped() )
{
bitBlt ( mOsci, 0, 0, mBack, 0, 0, -1, -1, TQt::CopyROP );
- tqrepaint();
+ repaint();
}
return;
}
@@ -497,7 +497,7 @@ void KJScope::scopeEvent(float *d, int size)
x++;
}
- tqrepaint();
+ repaint();
}
void KJScope::paint(TQPainter *p, const TQRect &)
@@ -517,7 +517,7 @@ void KJScope::mouseRelease(const TQPoint &, bool in)
return;
stop();
- parent()->tqrepaint(rect(), false);
+ parent()->repaint(rect(), false);
swapScope(/*Null*/ StereoFFT);
}
@@ -528,7 +528,7 @@ void KJScope::readConfig()
if ( v != Mono )
{
stop();
- parent()->tqrepaint(rect(), false);
+ parent()->repaint(rect(), false);
swapScope ( v );
return;
}
diff --git a/noatun/modules/kjofol-skin/kjwidget.cpp b/noatun/modules/kjofol-skin/kjwidget.cpp
index f9cb345a..737032cf 100644
--- a/noatun/modules/kjofol-skin/kjwidget.cpp
+++ b/noatun/modules/kjofol-skin/kjwidget.cpp
@@ -34,13 +34,13 @@ TQBitmap KJWidget::getMask(const TQImage &_rect, register TQRgb transparent)
return bm;
}
-void KJWidget::tqrepaint(bool me, const TQRect &r, bool clear)
+void KJWidget::repaint(bool me, const TQRect &r, bool clear)
{
TQPainter p(parent());
if (me)
paint(&p, r.isValid() ? r : rect());
else
- parent()->tqrepaint(r.isValid() ? r : rect(), clear);
+ parent()->repaint(r.isValid() ? r : rect(), clear);
}
const TQString &KJWidget::backgroundPressed(const TQString &bmp) const
diff --git a/noatun/modules/kjofol-skin/kjwidget.h b/noatun/modules/kjofol-skin/kjwidget.h
index a678e8a7..f64d2226 100644
--- a/noatun/modules/kjofol-skin/kjwidget.h
+++ b/noatun/modules/kjofol-skin/kjwidget.h
@@ -25,8 +25,8 @@ public:
virtual void readConfig() {}
// called when the mouse is moved while clicked in this widget
- // tqrepaint myself
- virtual void tqrepaint(bool me=true, const TQRect &rect=TQRect(), bool clear=false);
+ // repaint myself
+ virtual void repaint(bool me=true, const TQRect &rect=TQRect(), bool clear=false);
virtual TQString tip() { return 0; }
diff --git a/noatun/modules/kjofol-skin/kjbutton.cpp b/noatun/modules/kjofol-skin/kjbutton.cpp
index edd53e2b..795dedfb 100644
--- a/noatun/modules/kjofol-skin/kjbutton.cpp
+++ b/noatun/modules/kjofol-skin/kjbutton.cpp
@@ -165,9 +165,9 @@ void KJButton::showPressed(bool b)
{
mShowPressed = b;
if ( mShowPressed )
- tqrepaint(true); // tqrepaint with selected image
+ repaint(true); // repaint with selected image
else
- tqrepaint(false); // tqrepaint with default image (player-background)
+ repaint(false); // repaint with default image (player-background)
}
void KJButton::slotPlaylistShown(void)
@@ -193,8 +193,8 @@ void KJButton::slotEqEnabled(bool on)
void KJButton::mouseRelease(const TQPoint &, bool in)
{
- // tqrepaint with default image (player-background)
- tqrepaint(false);
+ // repaint with default image (player-background)
+ repaint(false);
if (!in) // only do something if users is still inside the button
return;